game={
	state:"loading",
	imageLoaded:false,
	loadingComplete:function(){
		for(s in game.sounds){
			if(!game.soundLoaded[s]){
				return false;
			}
		}
		if(!game.imageLoaded){
			return false;
		}
		
		return true;
	},
	time: 1,
	volume: .2,
	paused: true,
	cleanUp:function(){
		//todo:
		//	-loop through all levels
		//	-loop through all tiles
		//		-null monster's tile, monster
		//		-null item's tile, item
	},
	powerCurve:function(level){
		return Math.pow(level-1,2);
	},
	shallowPowerCurve:function(level){
		return game.powerCurve(level)*.02+1;
	},
	init: function(){
		game.time = 60*5.9;
		game.paused = false;
		
		$("#console").html("");
		
		//title
		//running 
		//dead
		
		game.state = "running";
		game.forgivyTime = false;
		
		game.log("Welcome to the Golden Krone Hotel!");
		
		game.setVolume(game.volume);
	},
	sounds:{
		explosion:	new Audio("sounds/Explosion71.wav"),
		levelUp:	new Audio("sounds/levelup.wav"),
		hit1:		new Audio("sounds/hit1.wav"),
		hit2:		new Audio("sounds/hit2.wav"),
		hit3:		new Audio("sounds/hit3.wav"),
		hit4:		new Audio("sounds/hit4.wav"),
		hit5:		new Audio("sounds/hit5.wav"),
		shock:		new Audio("sounds/shock-shorter.wav"),
		heal:		new Audio("sounds/heal-louder.wav"),
		ice:		new Audio("sounds/ice.wav"),
		firestorm:	new Audio("sounds/firestorm-quiter.wav"),
		gold:		new Audio("sounds/gold.wav"),
		silver:		new Audio("sounds/silver.wav"),
		blast:		new Audio("sounds/blast.wav"),
		death:		new Audio("sounds/death.wav"),
		title:		new Audio("sounds/AmazingPlan.mp3")
	},
	setSoundLoaded:function(){
		for(s in game.sounds){
			game.soundLoaded[s]=false;
			game.sounds[s].onloadeddata=(function(s){
				return function(){
					game.soundLoaded[s]=true;
				};
			})(s)
		}
	},
	soundLoaded:{},
	setVolume:function(newVolume){
		game.volume=newVolume;
	},
	playSound:function(soundName){
		if(game.soundLoaded[soundName]){
			game.sounds[soundName].volume = game.volume;
			game.sounds[soundName].pause();
			game.sounds[soundName].currentTime = 0;
			game.sounds[soundName].play();
		}else{
			setTimeout(function(){game.playSound(soundName)},100);
		}
	},
	stopSound:function(soundName){
		if(game.soundLoaded[soundName]){
			//game.sounds[soundName].pause();
			$(game.sounds[soundName]).animate({volume: 0}, 1500);
		}
	},
	updateScores:function(){
		var scores = game.getScores();
		var scoreHtml = "";
		
		if(scores.length>0){
			scoreHtml+='<table>';
			scoreHtml+='<tr><th colspan="5">Guestbook</th></tr>';
			scoreHtml+='<tr><th>Name</th><th>Arrival</th><th>Duration</th><th>Floor</th><th>Balance</th></tr>';
			for(var i=0;i<Math.min(5,scores.length);i++){
				scoreHtml+='<tr>'+
					'<td>S. Arobase</td>'+
					'<td>'+scores[i]['date']+'</td>'+
					'<td>'+scores[i]['days']+(scores[i]['days']> 1 ? " days":" day")+'</td>'+
					'<td>'+scores[i]['floor']+'</td>'+
					'<td>$'+scores[i]['gold']+'</td>';
			}
			scoreHtml+='</table>'
		}
		
		$("#guestbook").html(scoreHtml);
	},
	addScore: function(date, days, floor, gold){
		var scores = [];
		if(game.localStoragedSupported()){
			if(localStorage["gkh.scores"] && localStorage["gkh.scores"]!==	undefined){
				scores = JSON.parse(localStorage["gkh.scores"]);
			}
			
			scores.push({
				date: date,
				days: days,
				floor: floor,
				gold: gold
			});
			
			localStorage["gkh.scores"] = JSON.stringify(scores);
		}
	},
	getScores: function(){
		if(game.localStoragedSupported() && localStorage["gkh.scores"]){
			return JSON.parse(localStorage["gkh.scores"]).sort(function(a,b){
				return b.gold-a.gold;
			});
		}else{
			return [];
		}
	},
	localStoragedSupported: function() {
		try {
			return 'localStorage' in window && window['localStorage'] !== null;
		} catch (e) {
			return false;
		}
	},
	fullVisibilty: false,
	getTimeOfDay: function(){
		return game.time % (60*24);
	},
	getDay:function(){
		return Math.ceil(game.time / (60*24));
	},
	capitalize:function(s){
		return s[0].toUpperCase()+s.slice(1);
	},
	getTimeDescription:function(){
		var t = game.getTimeOfDay();
		
		var hour = Math.floor((t/60))%12;
		if(hour==0){
			hour+=12;
		}
		
		if(hour<10){
			hour = "&nbsp;"+hour;
		}
		
		var minute = Math.floor(t % 60);
		if(minute<10){
			minute = "0"+minute;
		}
		
		var description = "";
		description+=hour+":"+minute;
		if(t>=60*12){
			description+="pm";
		}else{
			description+="am";
		}
		
		return description;
	},
	getShortTimeDescription:function(){
		var t = game.getTimeOfDay();
		
		var hour = Math.floor((t/60))%12;
		if(hour==0){
			hour+=12;
		}
		
		if(hour<10){
			hour = "&nbsp;"+hour;
		}
		
		var minute = Math.floor(t % 60);
		if(minute<10){
			minute = "0"+minute;
		}
		
		var description = "";
		description+=hour+":"+minute;
		
		return description;
	},
	//to be called after a player performs an action
	tick:function(timeJump,skipDraw){
		//slowing down time here
		game.time+=timeJump/2.0;
		
		var monsters = map.getCurrentLevel().monsters;
		for(var i=monsters.length-1;i>=0;i--){
			if(monsters[i]!==null){
				monsters[i].peformActions(timeJump);
				monsters[i].update(timeJump);
			}
		}
		
		player.tick(timeJump);
		
		//remove blood
		for(var i=0;i<map.getCurrentLevel().levelSize;i++){
			for(var j=0;j<map.getCurrentLevel().levelSize;j++){
				var tile = map.getTile(i,j);
				if(tile.item!=null && tile.item.type =="blood"){
					tile.item.removeCounter-=timeJump/10.0;
					if(tile.item.removeCounter<=0){
						tile.item = null;
					}
				}
			}
		}
	
		lighting.initLightRound();
		lighting.calculateSunlight();
		lighting.calculateDynamicLighting();
		
		if(!skipDraw){
			drawCanvas();
		}
	},
	log:function(message){
		$("#console").append(
			'<table><tr><td style="color:#aaa;padding-right:10px;vertical-align:top;">'+game.getShortTimeDescription()+'</td><td>'+message+'</td></tr></table>'
		);
		$("#console").scrollTop($("#console")[0].scrollHeight);
	},
	chat:function(name, message, type){
		if(type=="human"){
			var nameColor = "rgb(255,221,17)";
		}else{
			var nameColor = "rgb(255,68,51)";
		}
		$("#console").append('<span style="font-weight:bold;color:'+nameColor+';">'+name+'</span> '+message+'<br>');
		$("#console").scrollTop($("#console")[0].scrollHeight);
	},
	showMenu:function(content){
		$("#modal").show();
		$("#modal").html(content);
		game.menuOpen = true;
	},
	closeMenu:function(){
		game.menuOpen = false;
		$("#modal").hide();
	},
	menuOpen: false,
	describe: function(i,j){
		var html = "";
		
		var tile = map.getTile(i,j);
		
		if(tile.light>=player.visibilityThreshold && tile.playerVisible){
			if(tile.i==player.x && tile.j==player.y){
				html+='<h1 class="description">Sorina Arobase</h1>';
				html+='<p>That\'s you!</p>';
			}
		
			html+='<h1 class="description">'+tile.name+'</h1>';
			html+='<p>'+tile.getDescription()+'</p>';
			
			if(tile.monster != null){
				html+='<h1 class="description">'+tile.monster.name+'</h1>';
				html+='<p>'+tile.monster.getDescription()+'</p>';
			}
			
			if(tile.torch == 1){
				html+='<h1 class="description">Unlit torch</h1>';
				html+='<p>You could light it yourself if you had some oil.</p>';
			}else if(tile.torch == 2){
				html+='<h1 class="description">Burning torch</h1>';
				html+='<p>You could extinguish that if you wanted to.</p>';
			}
			
			if(tile.item != null){
				html+='<h1 class="description">'+tile.item.getName()+'</h1>';
				html+='<p>'+tile.item.getDescription()+'</p>';
			}
		}else{
			html+='<h1 class="description">You can\'t make that out right now. Maybe if you get closer...</h1>';
		}	
		
		
		game.showMenu(html);
	},
	openPotionMenu:function(){
		var html = "";
		
		html+='<h1>Potions</h1>';
		
		html+='<table style="border-spacing: 0px">';
		
		var potionArray = player.getShuffledPotionArray();
		
		var hasPotions = false;
		
		for(var i=0;i<potionArray.length;i++){
			var q = potionArray[i][1];
			if(q>0){
				html+='<tr><td style="cursor:pointer" class="potion-list-name" data-potion="'+potionArray[i][0]+'">'+potions.getPotionName(potionArray[i][0])+'</td><td>'+q+'</td><td>'+
					'<button class="ui-button potion-button" data-potion="'+potionArray[i][0]+'">Quaff</button>'+
				'</td></tr>';
				hasPotions = true;
			}
		}
		
		html+='</table>';
		
		if(!hasPotions){
			html+='<div>No potions</div>';
		}else{
			html+='<div id="potion-description" style="padding:30px 20px 10px 20px;font-style:italic;"></div>';
		}
		
		game.showMenu(html);
	},
	describePotion:function(potionName){
		$("#potion-description").html(potions.getDescription(potionName));
	},
	addButtons:function(){
		var buttonHtml="";
		var playerTile = player.getTile();
		
		buttonHtml +='<div id="potion-button" class="ui-button">[P]otions</div>';
		buttonHtml +='<div id="ingame-help-button" class="ui-button">[?] Help</div>';
		buttonHtml +='<div id="ingame-options-button" class="ui-button">[O]ptions</div>';
		
		if(playerTile.type=="staircase"){
			buttonHtml +='<div id="staircase-button" class="ui-button context-button">[T]ake Stairs</div>';
		}

		if(playerTile.torch==1){
			buttonHtml +='<div id="e-button" class="ui-button context-button">[E]nkindle</div>';
		}else if(playerTile.torch==2){
			buttonHtml +='<div id="e-button" class="ui-button context-button">[E]xtinguish</div>';
		}
		
		if(playerTile.item!=null && playerTile.item.type=="book"){
			
			var buttonText;
			if(playerTile.item.bookType == 0){
				buttonHtml +='<div id="read-button" class="ui-button context-button">[R]ead Chronicle</div>';
			}else if(playerTile.item.bookType == 1){
				buttonHtml +='<div id="read-button" class="ui-button context-button">[R]ead Manual</div>';	
			}else if(playerTile.item.bookType == 2){
				buttonHtml +='<div id="read-button" class="ui-button context-button">[R]ead Grimoire</div>';	
			}else if(playerTile.item.bookType == 3){
				buttonHtml +='<div id="read-button" class="ui-button context-button">[R]ead Primer</div>';	
			}
		}
		
		if(game.forgivyTime){
			buttonHtml +='<div id="forgive-button" class="ui-button context-button">[F]orgive Fane</div>';
		}
		
		

		$("#button-container").append(buttonHtml);
	}
}