function Monster(){
	this.actionPoints = 0;
	this.destroyed = false;
	this.actionState = "wait";
	this.playerLastSeen = null;
	
	this.baseHp = 15;
	this.baseSpeed = 8;
	this.baseAttack = 5;
	this.baseDefense = 2;
	this.baseXp = 3;
	
	this.overrideFriendly = null;
	
	this.slowCounter = 0;
	
	this.regen = false;
	
	this.name = "";
	this.description = "";
}

Monster.prototype.getXpValue = function(){
	return this.xpValue;
}

Monster.prototype.calculateStats = function(){
	var curve = game.shallowPowerCurve(this.level);

	this.speed = curve*this.baseSpeed*this.speedMod;
	this.attack = curve*this.baseAttack*this.attackMod;
	this.defense = curve*this.baseDefense*this.defenseMod;
	this.maxHp = curve*this.baseHp*this.hpMod;
	this.hp = this.maxHp;
	this.xpValue = Math.ceil(game.powerCurve(this.level+1)*.25)+this.baseXp;
}

Monster.prototype.interact = function(){
	this.swap();
	
	var convo = this.convoArray[this.convoIndex%this.convoArray.length];
	this.convoIndex++;
	
	game.chat(this.givenName,convo, this.type);
}

Monster.prototype.getArticleName = function(){
	return "the "+this.name;
}

Monster.prototype.getDescription = function(){
	return this.description;
}

Monster.prototype.getName = function(){
	return this.name;
}

Monster.prototype.swap = function(){
	var playerTile = player.getTile();
	var monsterTile = this.tile;
	player.x=monsterTile.i;
	player.y=monsterTile.j;
	playerTile.monster = this;
	monsterTile.monster = null;
	this.tile = playerTile;
	this.actionPoints = 0;
}

Monster.prototype.draw= function(i,j){
	//ctx.globalAlpha = Math.min(1,this.light);
	//ctx.globalAlpha = 1.5;

	ctx.globalAlpha = 1;

	ssl = ssLocation(this.getSsIndex());
	ctx.drawImage(ss,ssl[0],ssl[1],16,16,i*tileSize,j*tileSize,tileSize,tileSize);
	
	if(!(player.getTile().isAdjacent(this.tile) || (player.los(player.x,player.y,this.tile.i,this.tile.j) && player.getTile().light>this.visibilityThreshold))){
		ssl = ssLocation(11);
		ctx.drawImage(ss,ssl[0],ssl[1],16,16,i*tileSize,j*tileSize,tileSize,tileSize);
	}
	
	//border
	//red background
	//green for HP
	
	if(this.hp<this.maxHp){
		ctx.fillStyle = "rgba(0,0,0,.8)";
		ctx.fillRect(i*tileSize+tileScaling*1,j*tileSize+tileScaling*13,tileScaling*14,tileScaling*3);
		
		ctx.fillStyle = "rgb(255,68,51)";
		ctx.fillRect(i*tileSize+tileScaling*2,j*tileSize+tileScaling*14,tileScaling*12,tileScaling*1);
		
		ctx.fillStyle = "#22cc11";
		ctx.fillRect(i*tileSize+tileScaling*2,j*tileSize+tileScaling*14,tileScaling*12*Math.max(0,this.hp/this.maxHp),tileScaling*1);
	}
}

Monster.prototype.getSsIndex = function(){
	return this.ssIndex;
}

Monster.prototype.isFriendly = function(){
	if(this.overrideFriendly!=null){
		if(this.overrideFriendly=="friendly"){
			return true;
		}else{
			return false;
		}
	}

	if(player.isVampire()){
		if(this.type=="vampire"){
			return true;
		}
	}else{
		if(this.type=="human"){
			return true;
		}
	}
	
	return false;
}

Monster.prototype.update = function(timeJump){
	this.slowCounter = Math.max(0,this.slowCounter - timeJump/40.0);
	if(this.regen){
		this.hp = Math.min(this.maxHp,this.hp+timeJump/30.0);
	}
}

Monster.prototype.hit = function(attack, magicName){
	var hpLoss = Math.floor(Math.max(0,attack - this.defense*Math.random()));
	this.hp -= hpLoss;
	
	if(player.isVampire()){
		if(Math.random()>.5){
			game.log("You claw at "+this.getArticleName()+".");
		}else{
			game.log("You bite "+this.getArticleName()+".");
		}
	}else{
		if(!magicName){
			game.log("You hit "+this.getArticleName()+" with your sword.");
		}else{
			game.log("You hit "+this.getArticleName()+" with "+magicName+".");
		}
	}
	
	this.bleed(hpLoss);
	
	this.checkHp();
	
	if(this.actionState =="wait"){
		this.actionState = "wander";
	}
}

Monster.prototype.bleed = function(bleedAmount){
	if(this.type=="rat" || this.type=="human"){
		if(bleedAmount>=5 && Math.random()<.666){
			var neighbors = this.tile.getAllNeighbors();
			for(var i=0;i<neighbors.length;i++){
				if(neighbors[i].type=="floor" && neighbors[i].item==null && neighbors[i].torch == 0 && !neighbors[i].equals(player.getTile())){
					var blood = new Blood(neighbors[i]);
					blood.health = bleedAmount;
					neighbors[i].item=blood;
					return;
				}
			}
		}
	}
}

Monster.prototype.checkHp = function(){
	if(this.hp<=0){
		game.log("You kill "+this.getArticleName());
		player.xp+=this.getXpValue();
		this.die();
		map.getCurrentLevel().destroyMonster(this.tile);
	}
}

Monster.prototype.die = function(){

}

Monster.prototype.peformActions= function(timeWindow){

	//todo: use time window somehow
	this.actionPoints+=Math.max(0,this.speed-this.slowCounter)*timeWindow/10.0;
	while(this.actionPoints >= 10 && !this.destroyed){
		this.actionPoints-=10;
	
		//pick a movement or attack
		
		if(player.getTile().isNearby(this.tile) && player.los(player.x,player.y,this.tile.i,this.tile.j) && player.getTile().light>this.visibilityThreshold){
			var canSee = true;
		}else{
			var canSee = false;
		}
		
		if(!this.isFriendly() && this.type=="human" && canSee && player.getTile().isNeighbor(this.tile) && Math.random()<this.spellChance/2.0){
			this.castMagic("firestorm");
			continue;
		}
		
		if(player.getTile().isAdjacent(this.tile)){
			if(!this.isFriendly()){
				//ATTACK HERE
				
				this.performAttack();
				continue;
			}else{
				this.actionState = "wander";
			}
		}
		
		if(!this.isFriendly() && canSee){
			this.playerLastSeen = player.getTile();
			this.actionState = "pursue";
		}else{
			if(this.actionState == "pursue"){
				if(this.playerLastSeen != null && this.playerLastSeen.equals(this.tile)){
					this.actionState = "wander";
				}	
			}else if(this.actionState == "wander"){
				if(Math.random()<.05){
					this.actionState = "wait";
				}
			}else if(this.actionState == "wait"){
				if(Math.random()<.05){
					this.actionState = "wander";
				}
			}
		}
		
		
		//wander
		if(this.actionState == "wander"){
			this.wander();
		}else if(this.actionState == "pursue"){
			if(this.isFriendly()){
				this.actionState = "wander";
			}else{
				this.pursue(canSee);
			}
		}
	}
}

Monster.prototype.performAttack = function(){
	player.hit(this.attack, this.getArticleName());
}

Monster.prototype.canMove = function(newTile){
	if(!(player.x == newTile.i && player.y == newTile.j) && newTile.isPassable() && newTile.type!="staircase" && newTile.monster === null){
		return true;
	}else{
		return false;
	}
}

Monster.prototype.wander = function(){
	if(this.name=="Fane")return;
	
	var passables = this.tile.getPassableNeighbors();
	
	if(passables.length>0){
		//todo: add in light preference
		
		var newTile = passables[map.randRange(0,passables.length-1)];
		if(this.canMove(newTile)){
			this.move(newTile);
		}
	}
}

Monster.prototype.move = function(newTile){
	this.tile.monster = null;
	this.tile = newTile;
	this.tile.monster = this;
}

Monster.prototype.pursue = function(canSee){
	//simple: pathfind to player everytime regardless of everything else.
	
	
	//todo:
	//	-check visibility, put threshold on each monster
	//	-track "last known location"
	//	-switch back to another state 
	
	if(this.type=="human" && canSee && (player.x==this.tile.i || player.y==this.tile.j)){
		if(Math.random()<this.spellChance){
			var spells = [
				"ice",
				"shock"
			]
			
			this.castMagic(spells[map.randRange(0,spells.length-1)]);
			return;
		}
		
	}
	
	
	
	
	if(this.playerLastSeen!=null){
		var pathfind = this.pathfind(this.playerLastSeen.i,this.playerLastSeen.j);
		if(pathfind!=null && this.canMove(pathfind)){
			this.move(pathfind);
		}else{
			if(Math.random()<.25){
				this.actionState = "wander";
			}
		}
	}
}

Monster.prototype.castMagic = function(spellName){
	var d = this.getPlayerDirection();
	
	game.log(game.capitalize(this.getArticleName())+" casts "+spellName.toUpperCase());
	magic.spells[spellName].cast(d,this.tile.i,this.tile.j,false);
}

Monster.prototype.getPlayerDirection = function(){
	if(player.x==this.tile.i){
		if(player.y<this.tile.j){
			return 1;
		}else{
			return 3;
		}
	}
	
	if(player.y==this.tile.j){
		if(player.x<this.tile.i){
			return 2;
		}else{
			return 0;
		}
	}
}

Monster.prototype.pathfind = function(x,y){
	var sourceTile = map.getTile(this.tile.i,this.tile.j);
    var destTile =  map.getTile(x,y);
	var manhattan = Math.abs(sourceTile.i-x)+Math.abs(sourceTile.j-y);
	
	if(Math.abs(sourceTile.i-x)>playerOffset || Math.abs(sourceTile.j-y)>playerOffset) return null;
	
	if(x==this.tile.i && y==this.tile.j) return;
    
    var displayTiles = map.getMonsterDisplayTiles(this.tile.i,this.tile.j);
    for(var i=0;i<displayTiles.length;i++){
        displayTiles[i].astar={
        	visited:false,
        	f:10000
        };
    }
    
    
    candidates = [sourceTile];

    sourceTile.astar.g=0;
    sourceTile.astar.f=manhattan;

    var timeout= 1000;
    while(candidates.length>0){
        timeout--;
        if(timeout<=0)break;
        
        candidates.sort(function(a,b){
           return a.astar.f - b.astar.f;
        });

        var c = candidates[0];

        //check for goal
        if(c.equals(destTile) && !c.equals(sourceTile)){
            var p = this.path(c,sourceTile);
            return p;
        }

        candidates.shift();
        
        c.astar.visited=true;
        
        var neighbors = c.getAdjacentNeighbors();
        
        for(var i=0;i<neighbors.length;i++){
        	var n = neighbors[i];

        	if(map.findTile(displayTiles,n)){
				if(n.astar.visited) continue;

				var tentative = c.astar.g+1;
				
				//we don't want to stop pathfinding through enemies, but we do want to discourage it
				if(!this.canMove(n)){
					tentative=1000;
				}
				
				var found =map.findTile(candidates,n);
				if(!found || n.astar.g > tentative){
					n.astar.from = c;
					n.astar.g=tentative;
					n.astar.f=n.astar.g+Math.abs(n.i-x)+Math.abs(n.j-y);
					
					if(!found && (n.isPassable() || n.equals(destTile))){
						candidates.push(n);
					}
				}
        	}
        }
    }
    return null;
}
                                             
Monster.prototype.path = function(tile, start){
    var from = tile.astar.from; 
    if(from.equals(start)){
         return tile;   
    }else{
         return this.path(from,start);
    }
}




function Grunt(tile){
	this.tile = tile;

	Monster.call(this);
	
	this.name = "Grunt";
	this.type="vampire";
	
	if(Math.random()<.5){
		this.gender = "male";
		this.givenName = maleNames[map.randRange(0,maleNames.length-1)];
	}else{
		this.gender = "female";
		this.givenName = femaleNames[map.randRange(0,femaleNames.length-1)];
	}
	
	this.ssIndex = 7;
	this.visibilityThreshold = -1;
	
	this.level = 		1;
	this.speedMod = 	1.6;
	this.attackMod = 	1.4;
	this.defenseMod = 	.7;
	this.hpMod =		1.0;
	
	this.calculateStats();
	
	this.convoArray = getConvo(tile.level.index);
	this.convoIndex = 0;
	
	this.description = "A low ranking vampire in Fane's personal army. It scouts the lower floors looking for a quick meal.";
}


Grunt.prototype = new Monster();
Grunt.prototype.constructor = Monster;


function Runner(tile){
	this.tile = tile;

	Monster.call(this);
	
	this.name = "Runner";
	this.type="vampire";
	
	if(Math.random()<.5){
		this.gender = "male";
		this.givenName = maleNames[map.randRange(0,maleNames.length-1)];
	}else{
		this.gender = "female";
		this.givenName = femaleNames[map.randRange(0,femaleNames.length-1)];
	}
	
	this.ssIndex = 82;
	this.visibilityThreshold = -1;
	
	this.level = 		4;
	this.speedMod = 	2.3;
	this.attackMod = 	1.5;
	this.defenseMod = 	.9;
	this.hpMod =		.9;
	
	this.calculateStats();
	
	this.convoArray = getConvo(tile.level.index);
	this.convoIndex = 0;
	
	this.description = "A mid-level vampire in Fane's personal army. It shuttles vials of blood back and forth for the nobility.";
}


Runner.prototype = new Monster();
Runner.prototype.constructor = Monster;



function Noble(tile){
	this.tile = tile;

	Monster.call(this);
	
	this.name = "Noble";
	this.type="vampire";
	
	if(Math.random()<.5){
		this.gender = "male";
		this.givenName = maleNames[map.randRange(0,maleNames.length-1)];
	}else{
		this.gender = "female";
		this.givenName = femaleNames[map.randRange(0,femaleNames.length-1)];
	}
	
	this.ssIndex = 98;
	this.visibilityThreshold = -1;
	
	this.level = 		7;
	this.speedMod = 	1.5;
	this.attackMod = 	1.7;
	this.defenseMod = 	1.6;
	this.hpMod =		1.6;
	
	this.calculateStats();
	
	this.convoArray = getConvo(tile.level.index);
	this.convoIndex = 0;
	
	this.description = "A vampire from the highest caste who has defected to Fane. These Nobles are quite well fed and extremely dangerous.";
}


Noble.prototype = new Monster();
Noble.prototype.constructor = Monster;





function Mercenary(tile){
	this.tile = tile;

	Monster.call(this);
		
	this.regen = true;
	
	if(Math.random()<.5){
		this.gender = "male";
		this.givenName = maleNames[map.randRange(0,maleNames.length-1)];
		this.ssIndex = 32;
	}else{
		this.gender = "female";
		this.givenName = femaleNames[map.randRange(0,femaleNames.length-1)];
		this.ssIndex = 33;
	}
	this.givenName += " "+surnames[map.randRange(0,surnames.length-1)];



	this.name = "Mercenary";
	this.type="human";

	this.visibilityThreshold = .4;

	this.spellChance = .25;
	this.spellLevel = 1;

	this.level = 		2;
	this.speedMod = 	1.0;
	this.attackMod = 	1.0;
	this.defenseMod = 	1.0;
	this.hpMod =		1.0;
	
	this.calculateStats();
	
	this.convoArray = getConvo(tile.level.index);
	this.convoIndex = 0;
	
	this.description = "A human initiate into Fane's personal army. They prove their worth by defending the lower levels.";
}


Mercenary.prototype = new Monster();
Mercenary.prototype.constructor = Monster;


function Marauder(tile){
	this.tile = tile;

	Monster.call(this);
		
	this.regen = true;
	
	if(Math.random()<.5){
		this.gender = "male";
		this.givenName = maleNames[map.randRange(0,maleNames.length-1)];
		this.ssIndex = 80;
	}else{
		this.gender = "female";
		this.givenName = femaleNames[map.randRange(0,femaleNames.length-1)];
		this.ssIndex = 81;
	}
	this.givenName += " "+surnames[map.randRange(0,surnames.length-1)];



	this.name = "Marauder";
	this.type="human";

	this.visibilityThreshold = .25;

	this.spellChance = .3;
	this.spellLevel = 2;

	this.level = 		5;
	this.speedMod = 	1.4;
	this.attackMod = 	1.3;
	this.defenseMod = 	1.5;
	this.hpMod =		1.0;
	
	this.calculateStats();
	
	this.convoArray = getConvo(tile.level.index);
	this.convoIndex = 0;
	
	this.description = "A well armed human who often makes night time visits into the nearby town for plunder. They have very rarely seen the sun and thus have improved night vision. They've sacrificed hands to demonstrate their loyalty to Fane.";
}

Marauder.prototype = new Monster();
Marauder.prototype.constructor = Monster;



function Solomonar(tile){
	this.tile = tile;

	Monster.call(this);
		
	this.regen = true;
	
	if(Math.random()<.5){
		this.gender = "male";
		this.givenName = maleNames[map.randRange(0,maleNames.length-1)];
	}else{
		this.gender = "female";
		this.givenName = femaleNames[map.randRange(0,femaleNames.length-1)];
	}
	this.givenName += " "+surnames[map.randRange(0,surnames.length-1)];

	this.ssIndex = 96;

	this.name = "Solomonar";
	this.type="human";

	this.visibilityThreshold = .35;

	this.spellChance = .666;
	this.spellLevel = 3;

	this.level = 		8;
	this.speedMod = 	1.1;
	this.attackMod = 	.6;
	this.defenseMod = 	.9;
	this.hpMod =		.8;
	
	this.calculateStats();
	
	this.convoArray = getConvo(tile.level.index);
	this.convoIndex = 0;
	
	this.description = "A human wizard who has studied magic for a very long time. An extremely dangerous foe.";
}

Solomonar.prototype = new Monster();
Solomonar.prototype.constructor = Monster;





function RatSoldier(tile){
	this.tile = tile;

	Monster.call(this);
	
	this.visibilityThreshold = .01;
	
	
	this.regen = true;
	
	this.ssIndex = 37;
	
	this.name = "Rat Soldier";
	this.type="rat";


	this.level = 		3;
	this.speedMod = 	2.0;
	this.attackMod = 	.8;
	this.defenseMod = 	.7;
	this.hpMod =		1.5;
	
	this.calculateStats();
	
	this.description = "An armored rat desperate for scraps.";
}


RatSoldier.prototype = new Monster();
RatSoldier.prototype.constructor = Monster;

function RatAssassin(tile){
	this.tile = tile;

	Monster.call(this);
	
	this.visibilityThreshold = .01;
	
	
	this.regen = true;
	
	this.ssIndex = 53;
	
	this.name = "Rat Assassin";
	this.type="rat";


	this.level = 		7;
	this.speedMod = 	2.5;
	this.attackMod = 	1.0;
	this.defenseMod = 	.7;
	this.hpMod =		1.6;
	
	this.calculateStats();
	
	this.description = "An armored rat. Fane accepts even the lowliest of creatures who pledge their lives and obedience.";
}


RatAssassin.prototype = new Monster();
RatAssassin.prototype.constructor = Monster;







function Moroi(tile){
	this.tile = tile;

	Monster.call(this);
	
	this.visibilityThreshold = .01;
	
	
	this.regen = true;
	
	this.ssIndex = 40;
	
	this.name = "Moroi";
	this.type="moroi";

	this.level = 		9;
	this.speedMod = 	1.3;
	this.attackMod = 	1.0;
	this.defenseMod = 	1.0;
	this.hpMod =		.6;
	
	this.calculateStats();
	
	this.description = "A spirit wandering the halls. It seeks to drain energy and light so that it may one day live again.";
}


Moroi.prototype = new Monster();
Moroi.prototype.constructor = Monster;


function GreenMan(tile){
	this.tile = tile;

	Monster.call(this);
	
	this.visibilityThreshold = .5;
	
	
	this.regen = true;
	
	this.ssIndex = 39;
	
	this.name = "Green Man";
	this.type="greenman";

	this.level = 		5;
	this.speedMod = 	.8;
	this.attackMod = 	1.1;
	this.defenseMod = 	2.0;
	this.hpMod =		1.5;
	
	this.upgraded=false;
	
	this.calculateStats();
	
	this.description = "A half human, half plant. It's fairly harmless, but with sunlight it grows stronger.";
}

GreenMan.prototype = new Monster();
GreenMan.prototype.constructor = Monster;

GreenMan.prototype.getSsIndex = function(){
	if(this.upgraded){
		return 57;
	}else{
		return 56;
	}
}

GreenMan.prototype.upgrade = function(){
	if(!this.upgraded){
		this.upgraded = true;
		game.log("The Green Man becomes more powerful in the sunlight");
	}
		
	this.level = 10;
	this.calculateStats();				
}


function LapisGolem(tile){
	this.tile = tile;

	Monster.call(this);
	
	this.visibilityThreshold = .25;
	
	
	this.regen = false;
	
	this.ssIndex = 38;
	
	this.name = "Lapis Golem";
	this.type="golem";

	this.level = 		6;
	this.speedMod = 	.4;
	this.attackMod = 	3.0;
	this.defenseMod = 	1.5;
	this.hpMod =		2.0;
	
	this.calculateStats();
	
	this.description = "A gigantic assembly of stone brought to life through magical means. It's slow but quite powerful.";
}


LapisGolem.prototype = new Monster();
LapisGolem.prototype.constructor = Monster;





function RubyGolem(tile){
	this.tile = tile;

	Monster.call(this);
	
	this.visibilityThreshold = .25;
	
	
	this.regen = false;
	
	this.ssIndex = 54;
	
	this.name = "Ruby Golem";
	this.type="golem";

	this.level = 		9;
	this.speedMod = 	.5;
	this.attackMod = 	3.0;
	this.defenseMod = 	1.5;
	this.hpMod =		2.0;
	
	this.calculateStats();
	
	this.description = "A gigantic assembly of gemstone brought to life through magical means. It's slow but quite powerful.";
}


RubyGolem.prototype = new Monster();
RubyGolem.prototype.constructor = Monster;











function Fane(tile){
	this.tile = tile;

	Monster.call(this);
	
	this.ssIndex = 22;
	this.visibilityThreshold = -1;
	
	this.name = "Fane";
	this.type="vampire";
	
	this.givenName = "Fane";
	
	this.level = 		12;
	this.speedMod = 	1.5;
	this.attackMod = 	1.5;
	this.defenseMod = 	.8;
	this.hpMod =		4.0;
	
	this.calculateStats();
	
	this.overrideFriendly = "friendly";
	
	this.description = "The Exiled Vampire Prince.";
	
	this.convos = [
		[player.firstName+", it's been almost 10 years...",function(){}],
		["I am so sorry for what I did. I didn't understand you. There's plenty I didn't understand.",function(){}],
		["After the war, I started taking soul elixirs to see what it was like... to be human. And I hated it!",function(){}],
		["I realized that you must hate being a vampire as much as I hate being a human.",function(){}],
		["I wanted a human bride and you were human and I rejected you. I was wrong.",function(){}],
		["So you see, it was I who wrote the letter.",function(){}],
		["It took me years in fact. Taking elixirs, slowly learning, writing, planning. Do you know how long it took to even find you?",function(){}],
		["I have nothing left. All I want now is your forgiveness.",function(){}],
		["Are you so desperate for the Golden Krone that you would still kill me?",function(){}],
		["Here. Take it.",function(t){
			t.ssIndex = 23;
			player.gold+=9000;
			game.playSound("gold");
			game.log("You receive the GOLDEN KRONE ($9000)");
		}],
		["In fact, take all my riches. Why do I care?",function(t){
			t.ssIndex = 24;
			player.gold+=1000;
			game.playSound("gold");
			game.log("You receive $1000.");
		}],
		["Forgive me or take my life. ",function(){
			game.forgivyTime = true;
		}],
		["So be it.",function(){
			game.forgivyTime = false;
		}],
	]
}

Fane.prototype = new Monster();
Fane.prototype.constructor = Monster;


Fane.prototype.interact = function(){
	if(this.convos.length>0){
		var convo = this.convos.shift();
		game.chat(this.givenName,convo[0], this.type);
		
		convo[1](this);
		
		if(this.convos.length==0){
			this.overrideFriendly = "enemy";
		}
	}
}

Fane.prototype.die = function(){
	//game.log("You've defeated FANE.");
	game.state = "won";
	
	player.gameOver(true);
}

Fane.prototype.getArticleName = function(){
	return "FANE";
}




surnames = [
	"Popescu",
	"Ionescu",
	"Popa",
	"Barbu",
	"Radu",
	"Serban",
	"Matei",
	"Dumitru",
	"Gheorghe",
	"Albu",
	"Cojocaru",
	"Lungu",
	"Lupei",
	"Vaduva",
	"Vasile",
	"Balan"
];

maleNames = [
	"Alin",
	"Alexandru",
	"Andrei",
	"Bogdan",
	"Ciprian",
	"Claudiu",
	"Cosmin",
	"Costache",
	"Decebal",
	"Dinu",
	"Dragos",
	"Dumitru",
	"Flaviu",
	"Gavril",
	"Grigore",
	"Horia",
	"Iancu",
	"Ion",
	"Laurentiu",
	"Luca",
	"Mihai",
	"Nelu",
	"Nicu",
	"Octavian",
	"Ovidiu",
	"Radu",
	"Razvan",
	"Sandu",
	"Silviu",
	"Stelian",
	"Traian",
	"Valentin",
	"Viorel",
	"Vlad"
]

femaleNames = [
	"Anca",
	"Andreea",
	"Bianca",
	"Camelia",
	"Catina",
	"Constanta",
	"Cosmina",
	"Crina",
	"Daciana",
	"Denisa",
	"Ecaterina",
	"Flavia",
	"Florina",
	"Georgeta",
	"Ilinca",
	"Ioana",
	"Iulia",
	"Lavinia",
	"Loredana",
	"Madalina",
	"Mircea",
	"Nicoleta",
	"Oana",
	"Olga",
	"Rahela",
	"Raluca",
	"Rozalia",
	"Stela",
	"Viorica"
]


convos= {
	generic:[
		[
			"Of course I fear Fane, but I'm more afraid of returning to Stritiba.",
			"An angry mob awaits me there.",
			"I would surely hang."
		],
		[
			"Can you spare a drink?",
			"Heh. Get it?"
		],
		[
			"I killed a man once.",
			"Well, I couldn't kill him twice now could I?"
		],
		[
			"Vampires have a Golden Krone.",
			"The krone worn by the human king is made of steel, fashioned from some weapon captured in battle.",
			"It tells you what each side values, no?"
		],
		[
			"Have much gold, do you?"
		],
		[
			"Hmph.",
			"Watch yourself."
		],
		[
			"I haven't seen you before.",
			"You know, Fane doesn't appreciate seeing his subjects wandering freely.",
			"Most won't even go near stairs."
		],
		[
			"Hotel? Pfft.",
			"I've slept in sewers nicer than this."
		],
		[
			"The Mercenaries defend.",
			"The Marauders raid Stritiba.",
			"The Solomonari? They study their magic."
		],
		[
			"The Grunts defend.",
			"The Runners transport blood.",
			"The Nobles drink."
		],
		[
			"Fane is paranoid about the security here.",
			"I heard he even hired artificers to create defensive golems.",
			"Golems!"
		],
		[
			"I miss the war.",
			"If you think blood flows here, well, you haven't seen war."
		],
		[
			"Get out of my way."
		],
		[
			"Blast!",
			"How does it work?!?!"
		]
	],
	early:[
		[
			"I've heard rumors that General Arobase was seen in the nearby town.",
			"Why would she visit a hell hole like Stritiba?"
		],
		[
			"It's said that Arobase worked as an assassin before the war.",
			"She'd disguise herself as some lowly servant to get close to her targets.",
			"It's said she tried that on Fane once, but he's still standing, right?",
			"What a poor assassin.... you had one job."
		],
		[
			"Arobase hates Fane.",
			"He's a vampire, sure, but it seems to go beyond that..."
		],
		[
			"You look a lot like General Arobase.",
			"But she'd never show her face in a place like this."
		],
		[
			"In the human cities, he's known as the Exiled Vampire Prince. He has a different name here...",
			"Collector of organs.",
			"Do I need to explain it?"
		],
		[
			"Was it political? Did he want to be seen as worldly?",
			"Who knows why Fane sought a human bride before the war.",
			"He hasn't cared much for companionship since then."
		],
		[
			"Got any spare Soul Elixirs?",
			"They're worth their weight in gold in Stritiba!"
		]
	],
	mid:[
		[
			"Fane makes alliances with vampire and human, but it's not out of tolerance.",
			"He has no respect for anyone, including his own kind.",
			"He had half the vampire nobility executed when they wouldn't support him during the war.",
			"He's a sociopath!"
		],
		[
			"It's said Fane takes organs from his enemies...",
			"Hands from his loyal servants...",
			"And from his lovers, well...."
		],
		[
			"Damn. That's some awful scar on your neck.",
			"There's a famous human with a scar like that.",
			"Received at the hands of Fane himself.",
			"Well, that's what they say at least."
		],
		[
			"You can't trust anyone.",
			"You'd be surprised at how many prominent humans were born vampires."
		]
	],
	late:[
		[
			"Merciful Fane. From his enemies, he takes organs.",
			"From his servants, he takes hands.",
			"From his lovers, he leaves only a scar.",
			"A sort of brand I guess."
		],
		[
			"Don't tell anyone know I said this but... even Fane has a soft spot.",
			"I heard he was engaged to a human before the war.",
			"He broke it off when he found out she was born vampire."
		],
		[
			"Soul Elixirs are the drug of the elite. They're so damn expensive.",
			"You'll only see the Vampire nobility toying with them.",
			"Or those vampires living as human of course.",
			"What a costly way of life!"
		]
	]
};



function getConvo(level){
	if(Math.random()<.5){
		return convos.generic[map.randRange(0,convos.generic.length-1)];
	}else{
		if(level<3){
			return convos.early[map.randRange(0,convos.early.length-1)];
		}else if(level<6){
			return convos.mid[map.randRange(0,convos.mid.length-1)];
		}else{
			return convos.late[map.randRange(0,convos.late.length-1)];
		}
	}
}