function Tile(){
	this.timesExplored = 0;
	this.light = 0;
	this.lightVisits = {};
	
	this.effects = [];
	this.explored = false;
	this.playerVisible = false;
	
	if(Math.random()<.5){
		this.preferredMonster = "human";
	}else{
		this.preferredMonster = "vampire";
	}
	
	this.description = "";
	
	this.tutorial = false;
	
	this.preferDoor = false;
	this.monster = null;
	
	this.penetrated = false;
	
	this.torch = 0;
	
	this.item = null;
	
	this.id = Math.random().toString();
}



Tile.prototype.getDescription = function(){
	return this.description;
}

Tile.prototype.draw= function(i,j){
	if(game.fullVisibilty){
		this.light = Math.max(1,this.light);
		this.playerVisible = true;
	}

	if(this.light>=player.visibilityThreshold && this.playerVisible){
		ctx.globalAlpha = Math.min(1,this.light*player.lightingMultiplier);
		if(player.isVampire()){
			ctx.globalAlpha = Math.max(.2,ctx.globalAlpha);
		}
		//ctx.globalAlpha = 1.5;
	
		ssl = ssLocation(this.getSsIndex());
		ctx.drawImage(ss,ssl[0],ssl[1],16,16,i*tileSize,j*tileSize,tileSize,tileSize);
		
		ctx.globalAlpha = 1;
		
		if(this.torch>0){
			ssl = ssLocation(4+this.torch);
			ctx.drawImage(ss,ssl[0],ssl[1],16,16,i*tileSize,j*tileSize,tileSize,tileSize);
		}
		
		
		if(this.item!=null){
			this.item.draw(i,j);
		}
		
		
		
		for(var k=0;k<this.effects.length;k++){
			ssl = ssLocation(this.effects[k]);
			ctx.drawImage(ss,ssl[0],ssl[1],16,16,i*tileSize,j*tileSize,tileSize,tileSize);
		}
		
		
		if(this.monster!==null){
			this.monster.draw(i,j);
		}
	}
}

Tile.prototype.stepOn = function(){
	if(this.item!=null){
		if(this.item.pickUp()){
			game.log("You pick up the "+this.item.getName()+".");
			this.item = null;
		}
	}
}

Tile.prototype.getSsIndex = function(){
	return this.ssIndex;
}

//assumes same level
Tile.prototype.equals = function(tile){
	return (this.i==tile.i && this.j==tile.j);
}

Tile.prototype.isPassable = function(){
	return this.passable;
}

Tile.prototype.generationExplore = function(){
	return this.timesExplored++;
}

Tile.prototype.getTimesExplored = function(){
	return this.timesExplored;
}

Tile.prototype.getAdjacentNeighbors = function(){
	return [
		this.level.getTile(this.i+1,this.j),
		this.level.getTile(this.i-1,this.j),
		this.level.getTile(this.i,this.j+1),
		this.level.getTile(this.i,this.j-1)
	];
}

Tile.prototype.getPassableNeighbors = function(){
	var passables = [];
	var neighbors = this.getAdjacentNeighbors();
	for(var i=0;i<neighbors.length;i++){
		if(neighbors[i].isPassable()){
			passables.push(neighbors[i]);
		}
	}
	return passables;
}

Tile.prototype.isAdjacent = function(tile){
	var neighbors = this.getAdjacentNeighbors();
	for(var i=0;i<neighbors.length;i++){
		if(neighbors[i].equals(tile)){
			return true;
		}
	}
	return false;
}

Tile.prototype.isNeighbor = function(tile){
	if(this.i>=tile.i-1
	&& this.i<=tile.i+1
	&& this.j>=tile.j-1
	&& this.j<=tile.j+1){
		return true;
	}else{
		return false;
	}
}

Tile.prototype.isNearby = function(tile){
	if(this.i>=tile.i-playerOffset
	&& this.i<=tile.i+playerOffset
	&& this.j>=tile.j-playerOffset
	&& this.j<=tile.j+playerOffset){
		return true;
	}else{
		return false;
	}
}

Tile.prototype.getAllNeighbors = function(){
	return [
		this.level.getTile(this.i+1,this.j),
		this.level.getTile(this.i-1,this.j),
		this.level.getTile(this.i,this.j+1),
		this.level.getTile(this.i,this.j-1),
		this.level.getTile(this.i+1,this.j+1),
		this.level.getTile(this.i-1,this.j-1),
		this.level.getTile(this.i-1,this.j+1),
		this.level.getTile(this.i+1,this.j-1),
	];
}





function StoneWall(i,j,level){
	this.i=i;
	this.j=j;
	this.level=level;

	Tile.call(this);
	
	this.ssIndex = 1;
	this.type = "wall";
	this.wallType = "stone";
	this.opaque = true;
	
	this.passable = false;
	this.name = "Stone Wall";
}

StoneWall.prototype = new Tile();
StoneWall.prototype.constructor = Tile;

StoneWall.prototype.getSsIndex = function(){
	if(this.penetrated){
		return 34;
	}else{
		return 1;
	}
}

StoneWall.prototype.getDescription = function(){
	if(this.penetrated){
		return "A half-demolished stone wall.";
	}else{
		return "Your run of the mill stone wall.";
	}
}



function Entry(i,j,level){
	this.i=i;
	this.j=j;
	this.level=level;

	Tile.call(this);
	
	this.ssIndex = 55;
	this.type = "wall";
	this.wallType = "entry";
	this.opaque = true;
	
	this.passable = false;
	this.name = "Entrance";
	
	this.description ="The entrance to the Golden Krone Hotel. Why check out now?";
}

Entry.prototype = new Tile();
Entry.prototype.constructor = Tile;





function WoodenWall(i,j,level){
	this.i=i;
	this.j=j;
	this.level=level;

	Tile.call(this);
	
	this.ssIndex = 16;
	this.type = "wall";
	this.wallType = "wooden";
	this.opaque = true;
	
	this.passable = false;
	this.name = "Wooden Wall";
}

WoodenWall.prototype = new Tile();
WoodenWall.prototype.constructor = Tile;

WoodenWall.prototype.getSsIndex = function(){
	if(this.penetrated){
		return 35;
	}else{
		return 16;
	}
}

WoodenWall.prototype.getDescription = function(){
	if(this.penetrated){
		return "A half-demolished wooden wall.";
	}else{
		return "Your standard wooden wall.";
	}
}



function StainedGlass(i,j,level){
	this.i=i;
	this.j=j;
	this.level=level;

	Tile.call(this);
	
	this.ssIndex = 18;
	this.type = "wall";
	this.wallType = "stained";
	this.opaque = true;
	
	this.passable = false;
	this.name = "Stained Glass";
}

StainedGlass.prototype = new Tile();
StainedGlass.prototype.constructor = Tile;


StainedGlass.prototype.getDescription = function(){
	if(this.penetrated){
		return "A once beautiful stained glass window. Colorful shards are scattered everywhere. It appears to have been smashed.";
	}else{
		return "An ornately designed stained glass window. It allows surprisingly little light through.";
	}
}

StainedGlass.prototype.getSsIndex = function(){
	if(this.penetrated){
		return 19;
	}else{
		return 18;
	}
}



function Floor(i,j,level){
	this.i=i;
	this.j=j;
	this.level=level;
	
	Tile.call(this);
	
	this.ssIndex = 0;
	this.type = "floor";
	this.opaque = false;
	
	this.passable = true;
	this.name = "Floor";
	
	this.description = "You wonder when the housekeepers last attended to this area.";
}

Floor.prototype = new Tile();
Floor.prototype.constructor = Tile;


function Staircase(i,j,level){
	this.i=i;
	this.j=j;
	this.level=level;
	
	Tile.call(this);
	
	this.ssIndex = 0;
	this.type = "staircase";
	this.opaque = false;
	
	this.direction = "down"
	
	this.passable = true;
	this.name = "Staircase";
}

Staircase.prototype = new Tile();
Staircase.prototype.constructor = Tile;

Staircase.prototype.getSsIndex = function(){
	if(this.direction=="down"){
		return 20;
	}else{
		return 21;
	}
}

Staircase.prototype.getDescription = function(){
	if(this.direction=="down"){
		return "A staircase leading down a floor.";
	}else{
		return "A staircase leading up a floor.";
	}
}


function Door(i,j,level){
	this.i=i;
	this.j=j;
	this.level=level;
	
	Tile.call(this);
	
	this.ssIndex = 17;
	this.type = "door";
	this.opaque = true;
	
	this.open = false;
	
	this.passable = false;
	this.name = "Door";
	
	this.description = "A closed door. Could be an open door one day.";
}

Door.prototype = new Tile();
Door.prototype.constructor = Tile;

Door.prototype.stepOn = function(){
	this.openDoor();
}

Door.prototype.openDoor = function(){
	this.level.setTile(this.i,this.j,new Floor(this.i,this.j,this.level),false);
}